@@ -12,7 +12,7 @@ $title = get_sub_field("title") ?? "";
             ?>
             <div class="swiper-pagination"></div>
             <div class="swiper-container banner-slider-swiper">
-                <div class="swiper-wrapper">   
+                <div class="swiper-wrapper" style="height: 430px;">   
                     <?php
                     while (have_rows('slides')) { 
                         the_row();
